@@ -20,6 +20,15 @@ test_that('lfda visualization works', {
   expect_that(plot(result, iris[,5]), not(throws_error()))
 })
 
+test_that('self visualization works', {
+  X <- iris[,-5]
+  Y <- iris[,5]
+  r <- 3
+  result <- self(X,Y,beta = 0.1, r = 3, metric = "plain")
+  options(rgl.useNULL=TRUE) # deal with rgl in Travis
+  expect_that(plot(result, iris[,5]), not(throws_error()))
+})
+
 test_that('exceptions are caught in visualization function', {
   k <- iris[,-5]
   y <- iris[,5]
@@ -31,4 +40,6 @@ test_that('exceptions are caught in visualization function', {
   expect_error(plot(result, iris[1:10,5]))
   expect_error(plot(result, iris[,5], cleanText=3))
   expect_that(plot(result, as.character(iris[,5])), not(throws_error()))
+  expect_warning(plot(lfda(k,y,4,metric="plain"), y))
+  expect_error(plot(lfda(k,y,2,metric="plain"), y))
 })
